@@ -9,9 +9,18 @@ import nltk
 import numpy as np
 import scipy.sparse as sp
 from gensim import corpora
+import fasttext
 
-from Orange.data import ContinuousVariable, DiscreteVariable, \
-    Domain, RowInstance, Table, StringVariable
+from Orange.data import (
+    Variable,
+    ContinuousVariable,
+    DiscreteVariable,
+    Domain,
+    RowInstance,
+    Table,
+    StringVariable,
+)
+from Orange.preprocess.transformation import Identity
 # uncomment when Orange3==3.27 is available
 # from Orange.data.util import get_unique_names
 # remove when Orange3==3.27 is available
@@ -74,6 +83,7 @@ class Corpus(Table):
         from orangecontrib.text.preprocess import PreprocessorList
         self.__used_preprocessor = PreprocessorList([])   # required for compute values
         self._titles: Optional[np.ndarray] = None
+        self.languages = None
         self._pp_documents = None  # preprocessed documents
 
         if domain is not None and text_features is None:
@@ -102,17 +112,49 @@ class Corpus(Table):
         else:
             raise NotImplementedError
 
-    def set_text_features(self, feats):
+    def _find_identical_feature(self, feature: Variable) -> Optional[Variable]:
+        """
+        Find a renamed feature in the domain which is identical to a feature.
+
+        Parameters
+        ----------
+        feature
+            A variable to find an identical variable in the domain.
+
+        Returns
+        -------
+        Variable which is identical to a feature (have different name but has
+        Identity(feature) in compute value.
+        """
+        for var in chain(self.domain.variables, self.domain.metas):
+            if (
+                var == feature
+                or isinstance(var.compute_value, Identity)
+                and var.compute_value.variable == feature
+            ):
+                return var
+        return None
+
+    def set_text_features(self, feats: Optional[List[Variable]]) -> None:
         """
         Select which meta-attributes to include when mining text.
 
-        Args:
-            feats (list or None): List of text features to include. If None infer them.
+        Parameters
+        ----------
+        feats
+            List of text features to include. If None infer them.
         """
         if feats is not None:
-            for f in feats:
+            feats = copy(feats)  # copy to not edit passed array inplace
+            for i, f in enumerate(feats):
                 if f not in chain(self.domain.variables, self.domain.metas):
-                    raise ValueError('Feature "{}" not found.'.format(f))
+                    # if not exact feature in the domain, it may be renamed
+                    # find identity - renamed feature
+                    id_feat = self._find_identical_feature(f)
+                    if id_feat is not None:
+                        feats[i] = id_feat
+                    else:
+                        raise ValueError('Feature "{}" not found.'.format(f))
             if len(set(feats)) != len(feats):
                 raise ValueError('Text features must be unique.')
             self.text_features = feats
@@ -184,6 +226,22 @@ class Corpus(Table):
             new_titles.append(t)
         return new_titles
 
+    def detect_languages(self):
+        """
+        Detects language of each document using fastText language
+        identification model.
+        [A. Joulin, E. Grave, P. Bojanowski, T. Mikolov,
+        Bag of Tricks for Efficient Text Classification],
+        [A. Joulin, E. Grave, P. Bojanowski, M. Douze, H. Jégou, T. Mikolov,
+        FastText.zip: Compressing text classification models]
+        """
+        path = os.path.join(os.path.dirname(__file__), 'models', 'lid.176.ftz')
+        model = fasttext.load_model(path)
+        texts = [' '.join(t.replace('\n', ' ').split(' ')[:2000])
+                 for t in self.documents]
+        self.languages = [model.predict(t)[0][0].replace('__label__', '')
+                          for t in texts]
+
     def _infer_text_features(self):
         """
         Infer which text features to use. If nothing was provided
@@ -305,7 +363,7 @@ class Corpus(Table):
                 class_vars=curr_class_var,
                 metas=curr_metas
         )
-        return Corpus(
+        c = Corpus(
             new_domain,
             X,
             self.Y.copy(),
@@ -313,6 +371,8 @@ class Corpus(Table):
             self.W.copy(),
             copy(self.text_features)
         )
+        Corpus.retain_preprocessing(self, c)
+        return c
 
     @property
     def documents(self):
@@ -359,7 +419,7 @@ class Corpus(Table):
         Args:
             tokens (list): List of lists containing tokens.
         """
-        self._tokens = np.array(tokens)
+        self._tokens = np.array(tokens, dtype=object)
         self._dictionary = dictionary or corpora.Dictionary(self.tokens)
 
     @property
@@ -551,6 +611,7 @@ class Corpus(Table):
         if isinstance(orig, Corpus):
             if isinstance(key, tuple):  # get row selection
                 key = key[0]
+
             if orig._tokens is not None:  # retain preprocessing
                 if isinstance(key, Integral):
                     new._tokens = np.array([orig._tokens[key]])
@@ -566,9 +627,22 @@ class Corpus(Table):
                 else:
                     raise TypeError('Indexing by type {} not supported.'.format(type(key)))
                 new._dictionary = orig._dictionary
+
+            if isinstance(new, Corpus):
+                # _find_identical_feature returns non when feature not found
+                # filter this Nones from list
+                new.text_features = list(filter(None, [
+                    new._find_identical_feature(tf)
+                    for tf in orig.text_features
+                ]))
+            else:
+                new.text_features = [
+                    tf
+                    for tf in orig.text_features
+                    if tf in set(new.domain.metas)
+                ]
+
             new._titles = orig._titles[key]
-            new_domain_metas = set(new.domain.metas)
-            new.text_features = [tf for tf in orig.text_features if tf in new_domain_metas]
             new.ngram_range = orig.ngram_range
             new.attributes = orig.attributes
             new.used_preprocessor = orig.used_preprocessor
