@@ -1,4 +1,5 @@
 import os
+import pickle
 import unittest
 
 import numpy as np
@@ -132,6 +133,35 @@ class CorpusTests(unittest.TestCase):
         )
         self.assertEqual(0, len(c.domain.attributes))
 
+    def test_extend_attribute_rename_text_features(self):
+        """
+        Test correctness of extending attributes, case when we want to rename
+        existing attributes
+        """
+        # corpus without features
+        c = Corpus.from_file('book-excerpts')
+        X = np.random.random((len(c), 2))
+        new_c = c.extend_attributes(X, ['Text', '2',], rename_existing=True)
+        self.assertEqual(new_c.X.shape, (len(c), 2))
+
+    def test_extend_attributes_keep_preprocessing(self):
+        """
+        Test if preprocessing remains when extending attributes
+        """
+        c = Corpus.from_file("book-excerpts")
+        c.store_tokens(c.tokens)
+
+        X = np.random.random((len(c), 3))
+        new_c = c.extend_attributes(X, ["1", "2", "3"])
+        self.assertEqual(new_c.X.shape, (len(c), 3))
+
+        self.assertEqual(len(new_c._tokens), len(c))
+        np.testing.assert_equal(new_c._tokens, new_c._tokens)
+        self.assertEqual(new_c._dictionary, c._dictionary)
+        self.assertEqual(new_c.text_features, c.text_features)
+        self.assertEqual(new_c.ngram_range, c.ngram_range)
+        self.assertEqual(new_c.attributes, c.attributes)
+
     def test_corpus_not_eq(self):
         c = Corpus.from_file('book-excerpts')
         n_doc = c.X.shape[0]
@@ -169,6 +199,18 @@ class CorpusTests(unittest.TestCase):
         np.testing.assert_equal(t.metas, c.metas)
         self.assertEqual(c.text_features, [t.domain.metas[0]])
 
+    def test_from_table_renamed(self):
+        c1 = Corpus.from_file('book-excerpts')
+        new_domain = Domain(c1.domain.attributes, metas=[c1.domain.metas[0].renamed("text1")])
+
+        # when text feature renamed
+        c2 = Corpus.from_table(new_domain, c1)
+        self.assertIsInstance(c2, Corpus)
+        self.assertEqual(len(c1), len(c2))
+        np.testing.assert_equal(c1.metas, c2.metas)
+        self.assertEqual(1, len(c2.text_features))
+        self.assertEqual("text1", c2.text_features[0].name)
+
     def test_infer_text_features(self):
         c = Corpus.from_file('friends-transcripts')
         tf = c.text_features
@@ -512,6 +554,33 @@ class CorpusTests(unittest.TestCase):
             domain, [["title1", "a"], ["title2", "b"]])
         assert_array_equal(["title1", "title2"], corpus.titles)
 
+    def test_pickle_corpus(self):
+        """
+        Corpus must be picklable (for save data widget)
+        gh-590
+        """
+        c = Corpus.from_file('book-excerpts')
+
+        # it must also work with preprocessed corpus
+        self.pp_list = [
+            preprocess.LowercaseTransformer(),
+            preprocess.WordPunctTokenizer(),
+            preprocess.SnowballStemmer(),
+            preprocess.FrequencyFilter(),
+            preprocess.StopwordsFilter()
+        ]
+        for pp in self.pp_list:
+            c = pp(c)
+        pickle.dumps(c)
+
+    def test_languages(self):
+        corpus = Corpus.from_file('deerwester')
+
+        self.assertIsNone(corpus.languages)
+        corpus.detect_languages()
+        self.assertEqual(len(corpus.languages), len(corpus))
+        self.assertListEqual(corpus.languages, ['en' for _ in range(len(corpus))])
+
 
 if __name__ == "__main__":
     unittest.main()
