@@ -90,6 +90,7 @@ class OWTwitter(OWWidget):
         api = Msg('Api error ({})')
         rate_limit = Msg('Rate limit exceeded. Please try again later.')
         empty_authors = Msg('Please provide some authors.')
+        wrong_authors = Msg('Query does not match Twitter user handle.')
         key_missing = Msg('Please provide a valid API key to get the data.')
 
     tweets_info = 'Tweets on output: {}'
@@ -107,6 +108,7 @@ class OWTwitter(OWWidget):
     attributes = [f.name for f in twitter.TwitterAPI.string_attributes]
     text_includes = Setting([f.name for f in twitter.TwitterAPI.text_features])
 
+
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
         self.api = None
@@ -207,6 +209,7 @@ class OWTwitter(OWWidget):
 
     @gui_require('api', 'key_missing')
     def run_search(self):
+        self.Error.clear()
         self.search()
 
     @asynchronous
@@ -223,6 +226,9 @@ class OWTwitter(OWWidget):
             if not self.word_list:
                 self.Error.empty_authors()
                 return None
+            if not any(a.startswith('@') for a in self.word_list):
+                self.Error.wrong_authors()
+                return None
             return self.api.search_authors(max_tweets=max_tweets,
                                            authors=self.word_list,
                                            collecting=self.collecting)
@@ -240,7 +246,6 @@ class OWTwitter(OWWidget):
 
     @search.on_start
     def on_start(self):
-        self.Error.clear()
         self.progressBarInit()
         self.search_button.setText('Stop')
         self.Outputs.corpus.send(None)
