@@ -10,6 +10,10 @@ from orangecontrib.text.widgets.owdocumentembedding import OWDocumentEmbedding
 from orangecontrib.text import Corpus
 
 
+async def none_method(_, __):
+    return None
+
+
 class TestOWDocumentEmbedding(WidgetTest):
 
     def setUp(self):
@@ -52,7 +56,7 @@ class TestOWDocumentEmbedding(WidgetTest):
         self.send_signal("Corpus", self.corpus)
         self.wait_until_finished()
         output_summary.assert_called_with(
-            str(int(len(self.corpus))),
+            f"{str(int(len(self.corpus)))}|0",
             "Successful: {}, Unsuccessful: {}".format(
                 int(len(self.corpus)), int(0)))
 
@@ -62,7 +66,9 @@ class TestOWDocumentEmbedding(WidgetTest):
         self.send_signal("Corpus", self.corpus)
         self.wait_until_finished()
         result = self.get_output(self.widget.Outputs.new_corpus)
-        self.assertGreater(len(self.corpus), len(result))
+        skipped = self.get_output(self.widget.Outputs.skipped)
+        self.assertIsNone(result)
+        self.assertEqual(len(skipped), len(self.corpus))
         self.assertTrue(self.widget.Warning.unsuccessful_embeddings.is_shown())
 
     @patch(PATCH_METHOD, make_dummy_post(b'{"embedding": [1.3, 1]}'))
@@ -73,7 +79,7 @@ class TestOWDocumentEmbedding(WidgetTest):
         self.assertIsNone(self.get_output(self.widget.Outputs.new_corpus))
 
     @patch('orangecontrib.text.vectorization.document_embedder' +
-           '.DocumentEmbedder.__call__',
+           '._ServerEmbedder.embedd_data',
            side_effect=EmbeddingConnectionError)
     def test_connection_error(self, _):
         self.send_signal("Corpus", self.corpus)
@@ -108,6 +114,15 @@ class TestOWDocumentEmbedding(WidgetTest):
             1, len(self.get_output(self.widget.Outputs.new_corpus))
         )
 
+    @patch('orangecontrib.text.vectorization.document_embedder' +
+           '._ServerEmbedder._encode_data_instance', none_method)
+    def test_skipped_documents(self):
+        self.send_signal("Corpus", self.corpus)
+        self.wait_until_finished()
+        self.assertIsNone(self.get_output(self.widget.Outputs.new_corpus))
+        self.assertEqual(len(self.get_output(self.widget.Outputs.skipped)), len(self.corpus))
+        self.assertTrue(self.widget.Warning.unsuccessful_embeddings.is_shown())
+
 
 if __name__ == "__main__":
     unittest.main()
